@@ -1,5 +1,49 @@
 """Command Module."""
 
+from qutrunk.circuit.parameter import Parameter
+
+
+class Amplitude:
+    """Set state-vector Amplitude.
+
+    Args:
+        reals: Amplitude read part.
+        imags: Amplitude imag part.
+        startind: Amplitude start index.
+        numamps: Amplitude number.
+    """
+
+    def __init__(self):
+        self.reals = []
+        self.imags = []
+        self.startind = 0
+        self.numamps = 0
+
+
+class Mat:
+    """Custom matrix.
+
+    Args:
+        reals: matrix read part.
+        imags: matrix imag part.
+        unitary: matrix is unitary or not
+    """
+    def __init__(self):
+        self.reals = []
+        self.imags = []
+        self.unitary = False
+
+
+class CmdEx:
+    """Command extension.
+
+    Args:
+        amp: Amplitude object.
+    """
+    def __init__(self, amp=None, mat=None):
+        self.amp = amp
+        self.mat = mat
+
 
 class Command:
     """Converts the quantum gate operation into a specific command.
@@ -12,25 +56,49 @@ class Command:
         inverse: Whether to enable the inverse circuit.
     """
 
-    def __init__(self, gate, targets, controls=None, rotation=None, inverse=False):
+    def __init__(
+        self,
+        gate,
+        targets=None,
+        controls=None,
+        rotation=None,
+        inverse=False,
+        cmdex=None,
+    ):
         # TODO: modify controls and rotation to tuple?
+        if targets is None:
+            self.targets = []
+        else:
+            self.targets = list(targets)
+
         if controls is None:
             self.controls = []
         else:
-            self.controls = controls
+            self.controls = list(controls)
 
         if rotation is None:
             self.rotation = []
         else:
-            self.rotation = rotation
+            self.rotation = list(rotation)
 
         self.gate = gate
-        self.targets = targets
         self.cmd_ver = "1.0"
         self.inverse = inverse
 
+        self.parameters = {}
+        for i, r in enumerate(self.rotation):
+            if isinstance(r, Parameter):
+                # map index to parameter
+                self.parameters[i] = r
+                r.host = self
+
+        # Command extention data
+        # TODO: extra
+        self.cmdex = cmdex
+
     def __eq__(self, other):
         """Two command are the same if they have the same qasm."""
+        # TODO: need to improve
         if type(self) is not type(other):
             return False
 
@@ -69,9 +137,8 @@ class Command:
             name = name.replace("c", "c" + str(ctrl_cnt), 1)
 
         angles_str = ""
-        angles = self.gate.angles()
-        if angles:
-            angles_str = "(" + ",".join([str(ag) for ag in angles]) + ")"
+        if len(self.rotation) > 0:
+            angles_str = "(" + ",".join([str(ag) for ag in self.rotation]) + ")"
 
         qubits_index = self.controls + self.targets
         qubits_str = ",".join([f"q[{qi}]" for qi in qubits_index])
@@ -80,17 +147,24 @@ class Command:
     def qusl(self) -> str:
         """Generate QuSL code for command."""
         name = str(self.gate)
+        if name == "AMP":
+            return f"AMP({self.gate.classicvector}, {self.gate.startind}, {self.gate.numamps}) * q"
+            # return 'AMP({}, {}, {}) * q'.format(self.gate.classicvector, self.gate.startind, self.gate.numamps)
+
         params = []
         param_str = ""
+        inv_str = ""
 
         # only append control bit count as param when it's more than one
+        if self.cmdex and self.cmdex.mat:
+            params += self.gate.matrix
+
         ctrl_cnt = len(self.controls)
         if ctrl_cnt:
             params.append(ctrl_cnt)
 
-        angles = self.gate.angles()
-        if angles:
-            params += angles
+        if len(self.rotation) > 0:
+            params += self.rotation
 
         if params:
             param_str = "(" + ", ".join([str(param) for param in params]) + ")"
@@ -102,7 +176,10 @@ class Command:
         if len(qubits_index) > 1:
             qubits_str = "(" + qubits_str + ")"
 
-        return name + param_str + " * " + qubits_str
+        if self.inverse:
+            inv_str += ".inv()"
+
+        return name + param_str + inv_str + " * " + qubits_str
 
     @property
     def name(self) -> str:
@@ -113,3 +190,15 @@ class Command:
     def num_qubits(self) -> int:
         """Return the number of qubits."""
         return len(self.controls) + len(self.targets)
+
+    def update_parameter(self, param):
+        """Update command parameter.
+
+        Usually, parameter is the angle of rotation gate
+
+        Args:
+            param: Parameter object holds parameter's name and value.
+        """
+        for k, v in self.parameters.items():
+            if v == param:
+                self.rotation[k] = v.value
