@@ -36,8 +36,7 @@ class HGate(BasicGate):
                 H * qr[0]
         """
         if not isinstance(qubit, QuBit):
-            # TODO:need to improve.
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         targets = [qubit.index]
         cmd = Command(self, targets, inverse=self.is_inverse)
@@ -50,13 +49,31 @@ class HGate(BasicGate):
     @property
     def matrix(self):
         """Access to the matrix property of this gate."""
-        return 1.0 / cmath.sqrt(2.0) * np.matrix([[1, 1], [1, -1]])
+        return 1.0 / cmath.sqrt(2.0) * np.array([[1, 1], [1, -1]])
 
     @property
     def label(self):
         """A label for identifying the gate."""
         self.__str__()
 
+    def inv(self):
+        """Return inverted H gate (itself)."""
+        gate = HGate()
+        gate.is_inverse = not self.is_inverse 
+        return gate
+
+    def ctrl(self, ctrl_cnt=1):
+        """Apply controlled gate.
+        
+        Args:
+            ctrl_cnt: The number of control qubits, default: 1.
+        """
+        if ctrl_cnt > 1:
+            raise ValueError("H gate do not support multiple control bits.")
+        gate = CHGate()
+        gate.is_inverse = self.is_inverse
+        return gate
+
 
 H = HGate()
 
@@ -91,12 +108,10 @@ class CHGate(BasicGate):
             AttributeError: If the argument is not a Qubit object.
         """
         if not all(isinstance(qubit, QuBit) for qubit in qubits):
-            # TODO:need to improve.
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         if len(qubits) != 2:
-            # TODO:need to improve.
-            raise AttributeError("Parameter error: One controlled and one target qubit are required.")
+            raise ValueError("Parameter error: One controlled and one target qubit are required.")
 
         self.qubits = qubits
         controls = [qubits[0].index]
@@ -125,5 +140,11 @@ class CHGate(BasicGate):
             ]
         )
 
+    def inv(self):
+        """Apply inverse gate."""
+        gate = CHGate()
+        gate.is_inverse = not self.is_inverse 
+        return gate
+
 
 CH = CHGate()
