@@ -22,7 +22,7 @@ class P(BasicPhaseGate):
 
     def __init__(self, alpha):
         if alpha is None:
-            raise NotImplementedError("The argument cannot be empty.")
+            raise ValueError("The argument cannot be empty.")
         super().__init__()
         self.rotation = alpha
 
@@ -41,11 +41,10 @@ class P(BasicPhaseGate):
                 P(alpha) * qr[0]
 
         Raises:
-            NotImplementedError: If the argument is not a Qubit object.
+            TypeError: If the argument is not a Qubit object.
         """
         if not isinstance(qubit, QuBit):
-            # TODO:need to improve.
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         targets = [qubit.index]
         cmd = Command(self, targets, rotation=[self.rotation], inverse=self.is_inverse)
@@ -60,6 +59,24 @@ class P(BasicPhaseGate):
         """Access to the matrix property of this gate."""
         return np.array([[1, 0], [0, np.exp(1j * self.rotation)]])
 
+    def inv(self):
+        """Apply inverse gate."""
+        gate = P(self.rotation)
+        gate.is_inverse = not self.is_inverse
+        return gate
+
+    def ctrl(self, ctrl_cnt=1):
+        """Apply controlled gate.
+
+        Args:
+            ctrl_cnt: The number of control qubits, default: 1.
+        """
+        if ctrl_cnt > 1:
+            raise ValueError("P gate do not support multiple control bits.")
+        gate = CP(self.rotation)
+        gate.is_inverse = self.is_inverse
+        return gate
+
 
 class CP(BasicRotateGate):
     """Control Phase Gate.
@@ -75,7 +92,7 @@ class CP(BasicRotateGate):
 
     def __init__(self, angle):
         if angle is None:
-            raise NotImplementedError("The argument cannot be empty.")
+            raise ValueError("The argument cannot be empty.")
         super().__init__()
         self.rotation = angle
 
@@ -97,12 +114,10 @@ class CP(BasicRotateGate):
             NotImplementedError: If the argument is not a Qubit object.
         """
         if not all(isinstance(qubit, QuBit) for qubit in qubits):
-            # TODO:need to improve.
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         if len(qubits) != 2:
-            # TODO:need to improve.
-            raise AttributeError(
+            raise ValueError(
                 "Parameter error：One controlled and one target qubit are required."
             )
 
@@ -122,4 +137,11 @@ class CP(BasicRotateGate):
     def matrix(self):
         """Access to the matrix property of this gate."""
         eith = np.exp(1j * float(self.rotation))
+        # TODO: ??
         return np.array([[1, 0, 0, 0], [0, 1, 0, 0], [0, 0, eith, 0], [0, 0, 0, 1]])
+
+    def inv(self):
+        """Apply inverse gate."""
+        gate = CP(self.rotation)
+        gate.is_inverse = not self.is_inverse
+        return gate
