@@ -1,3 +1,5 @@
+"""The S gate."""
+
 import numpy as np
 
 from .basicgate import BasicGate
@@ -35,7 +37,7 @@ class SGate(BasicGate):
             NotImplementedError: If the argument is not a Qubit object.
         """
         if not isinstance(qubit, QuBit):
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         targets = [qubit.index]
         cmd = Command(self, targets, inverse=self.is_inverse)
@@ -51,5 +53,11 @@ class SGate(BasicGate):
         """Access to the matrix property of this gate."""
         return np.matrix([[1, 0], [0, 1j]])
 
+    def inv(self):
+        """Apply inverse gate(SdgGate)."""
+        gate = SGate()
+        gate.is_inverse = not self.is_inverse
+        return gate
+
 
 S = SGate()
