@@ -37,7 +37,7 @@ class TdgGate(BasicGate):
             NotImplementedError: If the argument is not a Qubit object.
         """
         if not isinstance(qubit, QuBit):
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         targets = [qubit.index]
         cmd = Command(self, targets, inverse=self.is_inverse)
@@ -51,7 +51,14 @@ class TdgGate(BasicGate):
     @property
     def matrix(self):
         """Access to the matrix property of this gate."""
-        return np.matrix([[1, 0], [0, cmath.exp(1j * cmath.pi / 4)]]).getH()
+        m = np.array([[1, 0], [0, cmath.exp(1j * cmath.pi / 4)]])
+        return np.conjugate(m)
+
+    def inv(self):
+        """Apply inverse gate."""
+        gate = TdgGate()
+        gate.is_inverse = not self.is_inverse
+        return gate
 
 
 Tdg = TdgGate()
