@@ -30,9 +30,10 @@ class U3(BasicGate):
             phi: U3 gate parameter2.
             lam: U3 gate parameter3.
         """
-        if theta is None or phi is None or lam is None:
-            raise NotImplementedError("The argument cannot be empty.")
         super().__init__()
+
+        if theta is None or phi is None or lam is None:
+            raise ValueError("The argument cannot be empty.")
         self.theta = theta
         self.phi = phi
         self.lam = lam
@@ -52,11 +53,10 @@ class U3(BasicGate):
                 U3(pi/2,pi/2,pi/2) * qr[0]
 
         Raises:
-            NotImplementedError: If the argument is not a Qubit object.
+            TypeError: If the argument is not a Qubit object.
         """
         if not isinstance(qubit, QuBit):
-            # TODO: need to improve.
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         targets = [qubit.index]
         cmd = Command(
@@ -87,6 +87,24 @@ class U3(BasicGate):
             ]
         )
 
+    def inv(self):
+        """Apply inverse gate."""
+        gate = U3(self.theta, self.phi, self.lam)
+        gate.is_inverse = not self.is_inverse
+        return gate
+
+    def ctrl(self, ctrl_cnt=1):
+        """Apply controlled gate.
+        
+        Args:
+            ctrl_cnt: The number of control qubits, default: 1.
+        """
+        if ctrl_cnt > 1:
+            raise ValueError("U3 gate do not support multiple control bits.")
+        gate = CU3(self.theta, self.phi, self.lam)
+        gate.is_inverse = self.is_inverse
+        return gate
+
 
 class CU3(BasicRotateGate):
     """Control U3 gate.
@@ -111,7 +129,7 @@ class CU3(BasicRotateGate):
             lam: U3 gate parameter 3.
         """
         if theta is None or phi is None or lam is None:
-            raise NotImplementedError("The argument cannot be empty.")
+            raise ValueError("The argument cannot be empty.")
         super().__init__()
         self.theta = theta
         self.phi = phi
@@ -132,14 +150,14 @@ class CU3(BasicRotateGate):
                 CU3(pi/2,pi/2,pi/2) * (qr[0], qr[1])
 
         Raises:
-            NotImplementedError: If the argument is not a Qubit object.
-            AttributeError: If the qubits should not be two.
+            TypeError: If the argument is not a Qubit object.
+            ValueError: If the qubits should not be two.
         """
         if not all(isinstance(qubit, QuBit) for qubit in qubits):
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         if len(qubits) != 2:
-            raise AttributeError("Parameter Error: One controlled and one target qubit are required.")
+            raise ValueError("Parameter Error: One controlled and one target qubit are required.")
 
         controls = [qubits[0].index]
         targets = [qubits[1].index]
@@ -179,6 +197,12 @@ class CU3(BasicRotateGate):
             ]
         )
 
+    def inv(self):
+        """Apply inverse gate."""
+        gate = CU3(self.theta, self.phi,  self.lam)
+        gate.is_inverse = not self.is_inverse
+        return gate
+
 
 class CU(BasicRotateGate):
     """Control U gate.
@@ -204,7 +228,7 @@ class CU(BasicRotateGate):
             gamma: U gate parameter 4.
         """
         if theta is None or phi is None or lam is None or gamma is None:
-            raise NotImplementedError("The argument cannot be empty.")
+            raise ValueError("The argument cannot be empty.")
         super().__init__()
         self.theta = theta
         self.phi = phi
@@ -226,12 +250,10 @@ class CU(BasicRotateGate):
                 CU(pi/2,pi/2,pi/2,pi/2) * (qr[0], qr[1])
         """
         if not all(isinstance(qubit, QuBit) for qubit in qubits):
-            # TODO: need to improve.
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         if len(qubits) != 2:
-            # TODO: need to improve.
-            raise AttributeError("Parameter error: One controlled and one target qubit is required.")
+            raise ValueError("Parameter error: One controlled and one target qubit is required.")
 
         self.qubits = qubits
         controls = [qubits[0].index]
@@ -270,3 +292,9 @@ class CU(BasicRotateGate):
                 [0, c, 0, d],
             ]
         )
+
+    def inv(self):
+        """Apply inverse gate"""
+        gate = CU(self.theta, self.phi, self.lam, self.gamma)
+        gate.is_inverse = not self.is_inverse
+        return gate
