@@ -35,8 +35,7 @@ class XGate(BasicGate, Observable):
             NotImplementedError: If the argument is not a Qubit object.
         """
         if not isinstance(qubit, QuBit):
-            # TODO: need to improve.
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         targets = [qubit.index]
         cmd = Command(self, targets, inverse=self.is_inverse)
@@ -49,10 +48,11 @@ class XGate(BasicGate, Observable):
     @property
     def matrix(self):
         """Access to the matrix property of this gate."""
-        return np.matrix([[0, 1], [1, 0]])
+        return np.array([[0, 1], [1, 0]])
 
-    def obs(self, target):
-        """Get Observable data.
+    def __call__(self, target):
+        """
+        Get Observable data.
 
         Args:
             target: The observed qubit.
@@ -61,12 +61,26 @@ class XGate(BasicGate, Observable):
             The observed data list, each item contains op type and target qubit, \
                 e.g: [{"oper_type": 1, "target": 0}].
         """
-        puali_list = []
         pauli = {}
-        pauli["oper_type"] = PauliType.POT_PAULI_X.value
+        pauli["oper_type"] = PauliType.PAULI_X.value
         pauli["target"] = target.index
-        puali_list.append(pauli)
-        return puali_list
+        return pauli
+
+    def inv(self):
+        """Return inverted NOT gate (itself)."""
+        gate = XGate()
+        gate.is_inverse = not self.is_inverse
+        return gate
+
+    def ctrl(self, ctrl_cnt=1):
+        """Apply controlled gate.
+        
+        Args:
+            ctrl_cnt: The number of control qubits, default: 1.
+        """
+        gate = MCX(ctrl_cnt)
+        gate.is_inverse = self.is_inverse
+        return gate
 
 
 PauliX = X = NOT = XGate()
@@ -105,12 +119,11 @@ class MCX(BasicGate):
                 MCX(2) * (qr[0], qr[1], qr[2]) # qr[0], qr[1] are control qubits, qr[2] is target qubit
                 MCX(3) * (qr[0], qr[1], qr[2], qr[3])
         """
-        if isinstance(qubits, QuBit) or len(qubits) <= self.ctrl_cnt:
-            raise AttributeError("The parameter miss controlled or target qubit(s).")
-
         if not all(isinstance(qubit, QuBit) for qubit in qubits):
-            # TODO: need to improve.
-            raise AttributeError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
+
+        if len(qubits) <= self.ctrl_cnt:
+            raise ValueError("The parameter miss controlled or target qubit(s).")
 
         self.qubits = qubits
         controls = [q.index for q in qubits[0 : self.ctrl_cnt]]
@@ -128,6 +141,12 @@ class MCX(BasicGate):
         if self.ctrl_cnt == 1:
             return np.array([[1, 0, 0, 0], [0, 1, 0, 0], [0, 0, 0, 1], [0, 0, 1, 0]])
 
+    def inv(self):
+        """Apply inverse gate."""
+        gate = MCX(self.ctrl_cnt)
+        gate.is_inverse = not self.is_inverse
+        return gate
+
 
 CX = CNOT = MCX(1)
 Toffoli = MCX(2)
