@@ -44,9 +44,15 @@ class Z1Gate(BasicGate):
     @property
     def matrix(self):
         """Access to the matrix property of this gate."""
-        return np.matrix(
+        return np.array(
             [[np.exp(-1j * cmath.pi / 4), 0], [0, np.exp(1j * cmath.pi / 4)]]
         )
 
+    def inv(self):
+        """Apply inverse gate."""
+        gate = Z1Gate()
+        gate.is_inverse = not self.is_inverse
+        return gate
+
 
 Z1 = Z1Gate()
