@@ -2,11 +2,11 @@ from .bit import Bit
 
 
 class QuBit(Bit):
-    """ A quantum bit.
+    """A quantum bit.
 
     Args:
-        circuit: A quantum circuit.
-        index: The index of the bit in its containing register.
+        qreg(Qureg): A quantum register containing the bit.
+        index (int): The index of the bit in its containing register.
 
     Raises:
         TypeError: If the provided register is not a Qureg object.
@@ -18,7 +18,7 @@ class QuBit(Bit):
 
         if not isinstance(qreg, Qureg):
             raise TypeError(
-                f"QuBit needs a Qureg and {type(qreg).__name__} eas provided."
+                f"QuBit needs a Qureg and {type(qreg).__name__} was provided."
             )
 
         super().__init__(qreg, index)
