@@ -7,7 +7,7 @@ from numpy import pi
 
 from qutrunk.circuit import QCircuit
 from qutrunk.circuit.gates import Measure, All
-from qutrunk.circuit.ops import QSP, QAA
+from qutrunk.circuit.ops import PLUS, QAA
 
 
 def run_grover(qubits=10, backend=None):
@@ -32,9 +32,9 @@ def run_grover(qubits=10, backend=None):
     qureg = circuit.allocate(num_qubits)
 
     # Set inital amplitudes to plus state
-    QSP("+") * qureg
+    PLUS * qureg
 
-    # Apply quamtum operator(gates)
+    # Apply quantum operator(gates)
     QAA(num_reps, sol_elem) * qureg
 
     # Measure for all qubits
@@ -47,7 +47,7 @@ def run_grover(qubits=10, backend=None):
     out = res.get_outcome()
     print("measure result: " + str(int(out, base=2)))
 
-    # Print quantum circuit resource information 
+    # Print quantum circuit resource information
     circuit.show_resource()
 
     # Print quantum circuit execution information
