@@ -33,6 +33,3 @@ def run_random_byte(backend=None):
 if __name__ == "__main__":
     # Run locally
     circuit = run_random_byte()
-
-    # Dram quantum circuit
-    circuit.draw()
