@@ -43,7 +43,9 @@ class BinaryOperator(Node):
         try:
             return VALID_OPERATORS[self.value]
         except KeyError as ex:
-            raise NodeException(f"internal error: undefined operator '{self.value}'") from ex
+            raise NodeException(
+                f"internal error: undefined operator '{self.value}'"
+            ) from ex
 
     def qasm(self):
         """Return the QASM representation."""
