@@ -42,7 +42,9 @@ class UnaryOperator(Node):
         try:
             return VALID_OPERATORS[self.value]
         except KeyError as ex:
-            raise NodeException(f"internal error: undefined prefix '{self.value}'") from ex
+            raise NodeException(
+                f"internal error: undefined prefix '{self.value}'"
+            ) from ex
 
     def qasm(self):
         """Return QASM representation."""
