@@ -1,13 +1,15 @@
 """Run the quantum circuit using QuSprout as the backend."""
+from typing import Optional
+
+import qutrunk
+from qutrunk.circuit import QCircuit
+from qutrunk.backends import BackendQuSprout
+from qutrunk.circuit.gates import H, CNOT, Measure
 
 
-def run_check_sprout():
-    from qutrunk.circuit import QCircuit
-    from qutrunk.backends import BackendQuSprout
-    from qutrunk.circuit.gates import H, CNOT, Measure
-
+def run_check_sprout(ip: Optional[str] = None, port: Optional[int] = None):
     # allocate
-    qc = QCircuit(backend=BackendQuSprout())
+    qc = QCircuit(backend=BackendQuSprout(ip, port))
     qr = qc.allocate(2)
 
     # apply gate
@@ -25,7 +27,9 @@ def run_check_sprout():
     print(res.get_counts())
     print("===========circuit running info==========")
     print(res.excute_info())
-    print("QuTrunk is installed successfully! You can use QuTrunk now.")
+    print(
+        f"qutrunk {qutrunk.__version__} is installed successfully! You can use QuTrunk now."
+    )
 
 
 if __name__ == "__main__":
