@@ -39,17 +39,17 @@ def algorithm(file: dict):
         for c in file["cmd"]:
             f.write(c + "\n")
 
-        f.write("outcome = qc.get_prob_all_outcome([q.index for q in qr])\n")
-        # f.write("print(qc.get_prob_all_outcome([q.index for q in qr]))\n")
+        f.write("outcome = qc.get_probs()\n")
+        # f.write("print(qc.get_probs())\n")
         f.write("qc.run()\n")
         # f.write("print([int(q) for q in qr])\n")
 
         f.write("Tree = lambda: defaultdict(Tree)\n")
         f.write("tree = Tree()\n")
         c = [
-            "for index, item in enumerate(outcome):\n",
-            "    i = str(bin(index))[2:]\n",
-            "    tree['probs'][i]['probability'] = item\n",
+            "for _, item in enumerate(outcome):\n",
+            "    i = str(bin(item['idx']))[2:]\n",
+            "    tree['probs'][i]['probability'] = item['prob']\n",
             "    tree['probs'][i]['angle'] = 0\n",
         ]
         f.writelines(c)
